Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewClusterController ¶
func NewClusterController(clientset versioned.Interface, kubeClientset kubernetes.Interface) controller.Controller
NewClusterController returns new cluster controller.
Types ¶
type FakeClusterController ¶
type FakeClusterController struct {
*operator.FakeClusterOperator
// contains filtered or unexported fields
}
FakeClusterController can be used as a cluster controller in tests. It simulates the cluster controller behaviour with fake clientsets and a fake cluster operator.
func NewFakeClusterController ¶
func NewFakeClusterController(size int) (*watch.FakeWatcher, *FakeClusterController)
NewFakeClusterController returns new operator controller among with prepended watcher. Created controller uses fake clientSets and operator. Size indicates watcher events channel buffer.
Source Files
¶
- controller.go
- fake.go
- logging.go
Click to show internal directories.
Click to hide internal directories.